@@ -1,7 +1,7 @@
 /*===========================================================================*\
  *                                                                           *
  *                               OpenMesh                                    *
- *      Copyright (C) 2001-2014 by Computer Graphics Group, RWTH Aachen      *
+ *      Copyright (C) 2001-2015 by Computer Graphics Group, RWTH Aachen      *
  *                           www.openmesh.org                                *
  *                                                                           *
  *---------------------------------------------------------------------------*
@@ -34,8 +34,8 @@
 
 /*===========================================================================*\
  *                                                                           *
- *   $Revision: 990 $                                                         *
- *   $Date: 2014-02-05 10:01:07 +0100 (Mi, 05. Feb 2014) $                   *
+ *   $Revision: 1188 $                                                         *
+ *   $Date: 2015-01-05 16:34:10 +0100 (Mo, 05 Jan 2015) $                   *
  *                                                                           *
 \*===========================================================================*/
 
@@ -176,8 +176,6 @@ _OFFReader_::read_ascii(std::istream& _in, BaseImporter& _bi, Options& _opt) con
 {
 
 
-omlog() << "[OFFReader] : read ascii file\n";
-
   unsigned int            i, j, k, l, idx;
   unsigned int            nV, nF, dummy;
   OpenMesh::Vec3f         v, n;
@@ -433,8 +431,6 @@ void _OFFReader_::readValue(std::istream& _in, unsigned int& _value) const{
 bool
 _OFFReader_::read_binary(std::istream& _in, BaseImporter& _bi, Options& _opt, bool /*_swap*/) const
 {
-  omlog() << "[OFFReader] : read binary file\n";
-
   unsigned int            i, j, k, l, idx;
   unsigned int            nV, nF, dummy;
   OpenMesh::Vec3f         v, n;
